@@ -217,8 +217,11 @@ ect_real_get_text (ECellText *cell,
 
 static void
 ect_real_free_text (ECellText *cell,
+		    ETableModel *model,
+		    gint col,
                     gchar *text)
 {
+	e_table_model_free_value (model, col, text);
 }
 
 /* This is the default method for setting the ETableModel value based on
@@ -532,8 +535,8 @@ build_layout (ECellTextView *text_view,
 	if (text_view->edit || width <= 0)
 		return layout;
 
-	if (ect->font_name)
-	{
+	if (ect->font_name) {
+		PangoContext *pango_context;
 		PangoFontDescription *desc = NULL, *fixed_desc = NULL;
 		gchar *fixed_family = NULL;
 		gint fixed_size = 0;
@@ -546,7 +549,8 @@ build_layout (ECellTextView *text_view,
 			fixed_points = !pango_font_description_get_size_is_absolute (fixed_desc);
 		}
 
-		desc = pango_font_description_copy (gtk_widget_get_style (GTK_WIDGET (((GnomeCanvasItem *) ecell_view->e_table_item_view)->canvas))->font_desc);
+		pango_context = gtk_widget_get_pango_context (GTK_WIDGET (((GnomeCanvasItem *) ecell_view->e_table_item_view)->canvas));
+		desc = pango_font_description_copy (pango_context_get_font_description (pango_context));
 		pango_font_description_set_family (desc, fixed_family);
 		if (fixed_points)
 			pango_font_description_set_size (desc, fixed_size);
@@ -599,7 +603,7 @@ generate_layout (ECellTextView *text_view,
 	if (row >= 0) {
 		gchar *temp = e_cell_text_get_text (ect, ecell_view->e_table_model, model_col, row);
 		layout = build_layout (text_view, row, temp ? temp : "?", width);
-		e_cell_text_free_text (ect, temp);
+		e_cell_text_free_text (ect, ecell_view->e_table_model, model_col, temp);
 	} else
 		layout = build_layout (text_view, row, "Mumbo Jumbo", width);
 
@@ -705,21 +709,24 @@ ect_draw (ECellView *ecell_view,
 	CellEdit *edit = text_view->edit;
 	gboolean selected;
 	GtkWidget *canvas = GTK_WIDGET (text_view->canvas);
-	GtkStyle *style;
+	GdkRGBA fg_rgba, bg_rgba;
 	gint x_origin, y_origin, vspacing;
 
 	cairo_save (cr);
-	style = gtk_widget_get_style (canvas);
 
 	selected = flags & E_CELL_SELECTED;
 
 	if (selected) {
 		if (gtk_widget_has_focus (canvas))
-			gdk_cairo_set_source_color (cr, &style->fg[GTK_STATE_SELECTED]);
+			e_utils_get_theme_color (canvas, "theme_selected_fg_color", E_UTILS_DEFAULT_THEME_SELECTED_FG_COLOR, &fg_rgba);
 		else
-			gdk_cairo_set_source_color (cr, &style->fg[GTK_STATE_ACTIVE]);
+			e_utils_get_theme_color (canvas, "theme_unfocused_selected_fg_color,theme_selected_fg_color", E_UTILS_DEFAULT_THEME_UNFOCUSED_SELECTED_FG_COLOR, &fg_rgba);
+		gdk_cairo_set_source_rgba (cr, &fg_rgba);
 	} else {
-		gdk_cairo_set_source_color (cr, &style->text[GTK_STATE_NORMAL]);
+		gboolean color_overwritten = FALSE;
+
+		e_utils_get_theme_color (canvas, "theme_text_color", E_UTILS_DEFAULT_THEME_TEXT_COLOR, &fg_rgba);
+		gdk_cairo_set_source_rgba (cr, &fg_rgba);
 
 		if (ect->color_column != -1) {
 			gchar *color_spec;
@@ -728,8 +735,51 @@ ect_draw (ECellView *ecell_view,
 			color_spec = e_table_model_value_at (
 				ecell_view->e_table_model,
 				ect->color_column, row);
-			if (color_spec && gdk_color_parse (color_spec, &color))
+			if (color_spec && gdk_color_parse (color_spec, &color)) {
 				gdk_cairo_set_source_color (cr, &color);
+				color_overwritten = TRUE;
+			}
+
+			if (color_spec)
+				e_table_model_free_value (ecell_view->e_table_model, ect->color_column, color_spec);
+		}
+
+		if (!color_overwritten && ect->bg_color_column != -1) {
+			GdkColor bg_color;
+			gchar *color_spec;
+
+			/* if the background color is overwritten and the text color is not, then
+			   pick either black or white text color, because the theme text color might
+			   be hard to read on the overwritten background */
+			color_spec = e_table_model_value_at (
+				ecell_view->e_table_model,
+				ect->bg_color_column, row);
+
+			if (color_spec && gdk_color_parse (color_spec, &bg_color)) {
+				guint16 red, green, blue;
+				gdouble	cc = 65535.0;
+				GdkRGBA rgba;
+
+				red = bg_color.red;
+				green = bg_color.green;
+				blue = bg_color.blue;
+				rgba.alpha = 1.0;
+
+				if ((red / cc > 0.7) || (green / cc > 0.7) || (blue / cc > 0.7)) {
+					rgba.red = 0.0;
+					rgba.green = 0.0;
+					rgba.blue = 0.0;
+				} else {
+					rgba.red = 1.0;
+					rgba.green = 1.0;
+					rgba.blue = 1.0;
+				}
+
+				gdk_cairo_set_source_rgba (cr, &rgba);
+			}
+
+			if (color_spec)
+				e_table_model_free_value (ecell_view->e_table_model, ect->bg_color_column, color_spec);
 		}
 	}
 
@@ -759,9 +809,19 @@ ect_draw (ECellView *ecell_view,
 		if (edit->selection_start != edit->selection_end) {
 			cairo_region_t *clip_region;
 			gint indices[2];
-			GtkStateType state;
 
-			state = edit->has_selection ? GTK_STATE_SELECTED : GTK_STATE_ACTIVE;
+			if (edit->has_selection) {
+				if (gtk_widget_has_focus (canvas)) {
+					e_utils_get_theme_color (canvas, "theme_unfocused_selected_bg_color,theme_selected_bg_color", E_UTILS_DEFAULT_THEME_UNFOCUSED_SELECTED_BG_COLOR, &bg_rgba);
+					e_utils_get_theme_color (canvas, "theme_unfocused_selected_fg_color,theme_selected_fg_color", E_UTILS_DEFAULT_THEME_UNFOCUSED_SELECTED_FG_COLOR, &fg_rgba);
+				} else {
+					e_utils_get_theme_color (canvas, "theme_selected_bg_color", E_UTILS_DEFAULT_THEME_SELECTED_BG_COLOR, &bg_rgba);
+					e_utils_get_theme_color (canvas, "theme_selected_fg_color", E_UTILS_DEFAULT_THEME_SELECTED_FG_COLOR, &fg_rgba);
+				}
+			} else {
+				e_utils_get_theme_color (canvas, "theme_base_color", E_UTILS_DEFAULT_THEME_BASE_COLOR, &bg_rgba);
+				e_utils_get_theme_color (canvas, "theme_text_color", E_UTILS_DEFAULT_THEME_TEXT_COLOR, &fg_rgba);
+			}
 
 			indices[0] = MIN (edit->selection_start, edit->selection_end);
 			indices[1] = MAX (edit->selection_start, edit->selection_end);
@@ -772,10 +832,10 @@ ect_draw (ECellView *ecell_view,
 			cairo_clip (cr);
 			cairo_region_destroy (clip_region);
 
-			gdk_cairo_set_source_color (cr, &style->base[state]);
+			gdk_cairo_set_source_rgba (cr, &bg_rgba);
 			cairo_paint (cr);
 
-			gdk_cairo_set_source_color (cr, &style->text[state]);
+			gdk_cairo_set_source_rgba (cr, &fg_rgba);
 			cairo_move_to (cr, x_origin, y_origin);
 			pango_cairo_show_layout (cr, layout);
 		} else {
@@ -1143,7 +1203,7 @@ ect_enter_edit (ECellView *ecell_view,
 
 	temp = e_cell_text_get_text (ect, ecell_view->e_table_model, model_col, row);
 	edit->old_text = g_strdup (temp);
-	e_cell_text_free_text (ect, temp);
+	e_cell_text_free_text (ect, ecell_view->e_table_model, model_col, temp);
 	edit->text = g_strdup (edit->old_text);
 
 	if (edit->im_context) {
@@ -1309,7 +1369,6 @@ ect_print (ECellView *ecell_view,
 	ECellText *ect = E_CELL_TEXT (ecell_view->ecell);
 	ECellTextView *ectView = (ECellTextView *) ecell_view;
 	GtkWidget *canvas = GTK_WIDGET (ectView->canvas);
-	GtkStyle *style;
 	PangoDirection dir;
 	gboolean strikeout, underline;
 	cairo_t *cr;
@@ -1331,10 +1390,9 @@ ect_print (ECellView *ecell_view,
 	cairo_rectangle (cr, 2, 2, width + 2, height + 2);
 	cairo_clip (cr);
 
-	style = gtk_widget_get_style (canvas);
 	pango_context = gtk_widget_get_pango_context (canvas);
 	font_metrics = pango_context_get_metrics (
-		pango_context, style->font_desc,
+		pango_context, NULL,
 		pango_context_get_language (pango_context));
 	ty = (gdouble)(text_height -
 		pango_font_metrics_get_ascent (font_metrics) -
@@ -1386,7 +1444,7 @@ ect_print (ECellView *ecell_view,
 
 	pango_font_description_free (font_des);
 	g_object_unref (layout);
-	e_cell_text_free_text (ect, string);
+	e_cell_text_free_text (ect, ecell_view->e_table_model, model_col, string);
 }
 
 static gdouble
@@ -1942,6 +2000,8 @@ e_cell_text_get_text (ECellText *cell,
 
 void
 e_cell_text_free_text (ECellText *cell,
+		       ETableModel *model,
+		       gint col,
                        gchar *text)
 {
 	ECellTextClass *class;
@@ -1952,7 +2012,7 @@ e_cell_text_free_text (ECellText *cell,
 	if (class->free_text == NULL)
 		return;
 
-	class->free_text (cell, text);
+	class->free_text (cell, model, col, text);
 }
 
 void
@@ -2800,7 +2860,7 @@ e_cell_text_get_text_by_view (ECellView *cell_view,
 			E_CELL_TEXT (cell_view->ecell),
 			cell_view->e_table_model, col, row);
 		ret = g_strdup (model_text);
-		e_cell_text_free_text (E_CELL_TEXT (cell_view->ecell), model_text);
+		e_cell_text_free_text (E_CELL_TEXT (cell_view->ecell), cell_view->e_table_model, col, model_text);
 	}
 
 	return ret;
