@@ -60,7 +60,7 @@ handle_file_request (GSimpleAsyncResult *res,
 
 		stream = g_memory_input_stream_new_from_data (
 				contents, length, (GDestroyNotify) g_free);
-		g_simple_async_result_set_op_res_gpointer (res, stream, NULL);
+		g_simple_async_result_set_op_res_gpointer (res, stream, g_object_unref);
 	}
 }
 
@@ -130,6 +130,8 @@ file_request_send_finish (SoupRequest *request,
 
 	if (!stream) /* We must always return something */
 		stream = g_memory_input_stream_new ();
+	else
+		g_object_ref (stream);
 
 	return stream;
 }
