@@ -531,19 +531,13 @@ build_dialog (GtkWindow *parent,
 		"/org/gnome/evolution/mail/send-recv-window/",
 		E_RESTORE_WINDOW_SIZE);
 
-	gtk_widget_ensure_style ((GtkWidget *) gd);
-
 	container = gtk_dialog_get_action_area (gd);
 	gtk_container_set_border_width (GTK_CONTAINER (container), 6);
 
 	container = gtk_dialog_get_content_area (gd);
 	gtk_container_set_border_width (GTK_CONTAINER (container), 0);
 
-	cancel_button = gtk_button_new_with_mnemonic (_("Cancel _All"));
-	gtk_button_set_image (
-		GTK_BUTTON (cancel_button),
-		gtk_image_new_from_stock (
-			GTK_STOCK_CANCEL, GTK_ICON_SIZE_BUTTON));
+	cancel_button = e_dialog_button_new_with_icon ("process-stop", _("Cancel _All"));
 	gtk_widget_show (cancel_button);
 	gtk_dialog_add_action_widget (gd, cancel_button, GTK_RESPONSE_CANCEL);
 
@@ -636,7 +630,7 @@ build_dialog (GtkWindow *parent,
 			_("Updating...") : _("Waiting..."));
 		gtk_widget_set_margin_bottom (progress_bar, 12);
 
-		cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+		cancel_button = e_dialog_button_new_with_icon ("process-stop", _("_Cancel"));
 		gtk_widget_set_valign (cancel_button, GTK_ALIGN_END);
 		gtk_widget_set_margin_bottom (cancel_button, 12);
 
@@ -718,7 +712,7 @@ build_dialog (GtkWindow *parent,
 			GTK_PROGRESS_BAR (progress_bar), _("Waiting..."));
 		gtk_widget_set_margin_bottom (progress_bar, 12);
 
-		cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+		cancel_button = e_dialog_button_new_with_icon ("process-stop", _("_Cancel"));
 		gtk_widget_set_valign (cancel_button, GTK_ALIGN_END);
 
 		gtk_misc_set_alignment (GTK_MISC (label), 0, .5);
@@ -1118,15 +1112,19 @@ receive_update_got_folderinfo (GObject *source_object,
 
 	/* Ignore cancellations. */
 	if (g_error_matches (local_error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
-		g_warn_if_fail (info != NULL);
+		g_warn_if_fail (info == NULL);
 		g_error_free (local_error);
 
+		receive_done (send_info);
+
 	/* XXX Need to hand this off to an EAlertSink. */
 	} else if (local_error != NULL) {
-		g_warn_if_fail (info != NULL);
+		g_warn_if_fail (info == NULL);
 		g_warning ("%s: %s", G_STRFUNC, local_error->message);
 		g_error_free (local_error);
 
+		receive_done (send_info);
+
 	/* CamelFolderInfo may be NULL even if no error occurred. */
 	} else if (info != NULL) {
 		GPtrArray *folders = g_ptr_array_new ();
