@@ -319,10 +319,13 @@ mail_shell_view_key_press_event_cb (EMailShellView *mail_shell_view,
 		case GDK_KEY_Up:
 		case GDK_KEY_Right:
 		case GDK_KEY_Down:
-		case GDK_KEY_Prior:
 		case GDK_KEY_Next:
 		case GDK_KEY_End:
 		case GDK_KEY_Begin:
+			/* If Caret mode is enabled don't try to process these keys */
+			if (e_web_view_get_caret_mode (E_WEB_VIEW (mail_display)))
+				return FALSE;
+		case GDK_KEY_Prior:
 			if (!mail_shell_view_mail_display_needs_key (mail_display, FALSE) &&
 			    webkit_web_view_get_main_frame (WEBKIT_WEB_VIEW (mail_display)) !=
 			    webkit_web_view_get_focused_frame (WEBKIT_WEB_VIEW (mail_display))) {
@@ -564,7 +567,7 @@ mail_shell_view_search_filter_changed_cb (EMailShellView *mail_shell_view)
 void
 e_mail_shell_view_private_init (EMailShellView *mail_shell_view)
 {
-	g_signal_connect (
+	e_signal_connect_notify (
 		mail_shell_view, "notify::view-id",
 		G_CALLBACK (mail_shell_view_notify_view_id_cb), NULL);
 }
@@ -905,10 +908,12 @@ e_mail_shell_view_update_sidebar (EMailShellView *mail_shell_view)
 	ESourceRegistry *registry;
 	CamelStore *parent_store;
 	CamelFolder *folder;
+	CamelFolderInfoFlags flags = 0;
+	MailFolderCache *folder_cache;
 	MessageList *message_list;
 	guint selected_count;
 	GString *buffer;
-	gboolean store_is_local;
+	gboolean store_is_local, is_inbox;
 	const gchar *display_name;
 	const gchar *folder_name;
 	const gchar *uid;
@@ -953,6 +958,11 @@ e_mail_shell_view_update_sidebar (EMailShellView *mail_shell_view)
 	folder_name = camel_folder_get_display_name (folder);
 	parent_store = camel_folder_get_parent_store (folder);
 
+	folder_cache = e_mail_session_get_folder_cache (
+		e_mail_backend_get_session (E_MAIL_BACKEND (shell_backend)));
+	mail_folder_cache_get_folder_info_flags (folder_cache, parent_store, folder_name, &flags);
+	is_inbox = (flags & CAMEL_FOLDER_TYPE_MASK) == CAMEL_FOLDER_TYPE_INBOX;
+
 	num_deleted = camel_folder_summary_get_deleted_count (folder->summary);
 	num_junked = camel_folder_summary_get_junk_count (folder->summary);
 	num_junked_not_deleted =
@@ -1012,19 +1022,19 @@ e_mail_shell_view_update_sidebar (EMailShellView *mail_shell_view)
 		}
 
 	/* "Drafts" folder */
-	} else if (em_utils_folder_is_drafts (registry, folder)) {
+	} else if (!is_inbox && em_utils_folder_is_drafts (registry, folder)) {
 		g_string_append_printf (
 			buffer, ngettext ("%d draft", "%d drafts",
 			num_visible), num_visible);
 
 	/* "Outbox" folder */
-	} else if (em_utils_folder_is_outbox (registry, folder)) {
+	} else if (!is_inbox && em_utils_folder_is_outbox (registry, folder)) {
 		g_string_append_printf (
 			buffer, ngettext ("%d unsent", "%d unsent",
 			num_visible), num_visible);
 
 	/* "Sent" folder */
-	} else if (em_utils_folder_is_sent (registry, folder)) {
+	} else if (!is_inbox && em_utils_folder_is_sent (registry, folder)) {
 		g_string_append_printf (
 			buffer, ngettext ("%d sent", "%d sent",
 			num_visible), num_visible);
@@ -1172,6 +1182,56 @@ send_receive_account_item_activate_cb (GtkMenuItem *menu_item,
 	mail_receive_service (service);
 }
 
+typedef struct _EMenuItemSensitivityData {
+	GObject *service;
+	GtkWidget *menu_item;
+} EMenuItemSensitivityData;
+
+static void
+free_menu_item_sensitivity_data (gpointer ptr)
+{
+	EMenuItemSensitivityData *data = ptr;
+
+	if (!data)
+		return;
+
+	g_object_unref (data->service);
+	g_object_unref (data->menu_item);
+	g_free (data);
+}
+
+static gboolean
+update_menu_item_sensitivity_cb (gpointer user_data)
+{
+	EMenuItemSensitivityData *data = user_data;
+	gboolean is_online = FALSE;
+
+	g_return_val_if_fail (data != NULL, FALSE);
+
+	g_object_get (data->service, "online", &is_online, NULL);
+
+	gtk_widget_set_sensitive (data->menu_item, is_online);
+
+	return FALSE;
+}
+
+static void
+service_online_state_changed_cb (GObject *service,
+				 GParamSpec *param,
+				 GObject *menu_item)
+{
+	EMenuItemSensitivityData *data;
+
+	g_return_if_fail (G_IS_OBJECT (service));
+	g_return_if_fail (GTK_IS_WIDGET (menu_item));
+
+	data = g_new0 (EMenuItemSensitivityData, 1);
+	data->service = g_object_ref (service);
+	data->menu_item = g_object_ref (menu_item);
+
+	g_idle_add_full (G_PRIORITY_HIGH_IDLE, update_menu_item_sensitivity_cb, data, free_menu_item_sensitivity_data);
+}
+
 static void
 send_receive_add_to_menu (SendReceiveData *data,
                           CamelService *service,
@@ -1201,10 +1261,10 @@ send_receive_add_to_menu (SendReceiveData *data,
 		else
 			object = camel_service_ref_session (service);
 
-		g_object_bind_property (
-			object, "online",
-			menu_item, "sensitive",
-			G_BINDING_SYNC_CREATE);
+		e_signal_connect_notify_object (
+			object, "notify::online",
+			G_CALLBACK (service_online_state_changed_cb), menu_item,
+			0);
 
 		g_object_unref (object);
 	}
