@@ -59,7 +59,7 @@ enum {
 
 /* Forward Declarations */
 static void	e_shell_sidebar_alert_sink_init
-					(EAlertSinkInterface *interface);
+					(EAlertSinkInterface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (
 	EShellSidebar,
@@ -294,6 +294,21 @@ shell_sidebar_size_allocate (GtkWidget *widget,
 		gtk_widget_size_allocate (child, &child_allocation);
 }
 
+static void
+shell_sidebar_style_updated (GtkWidget *widget)
+{
+	EShellSidebar *shell_sidebar;
+	GdkRGBA bg;
+
+	/* Chain up to parent's method. */
+	GTK_WIDGET_CLASS (e_shell_sidebar_parent_class)->style_updated (widget);
+
+	shell_sidebar = E_SHELL_SIDEBAR (widget);
+
+	e_utils_get_theme_color (shell_sidebar->priv->event_box, "theme_bg_color", E_UTILS_DEFAULT_THEME_BG_COLOR, &bg);
+	gtk_widget_override_background_color (shell_sidebar->priv->event_box, GTK_STATE_FLAG_NORMAL, &bg);
+}
+
 static void
 shell_sidebar_forall (GtkContainer *container,
                       gboolean include_internals,
@@ -351,6 +366,7 @@ e_shell_sidebar_class_init (EShellSidebarClass *class)
 	widget_class->get_preferred_width = shell_sidebar_get_preferred_width;
 	widget_class->get_preferred_height = shell_sidebar_get_preferred_height;
 	widget_class->size_allocate = shell_sidebar_size_allocate;
+	widget_class->style_updated = shell_sidebar_style_updated;
 
 	container_class = GTK_CONTAINER_CLASS (class);
 	container_class->forall = shell_sidebar_forall;
@@ -423,20 +439,19 @@ e_shell_sidebar_class_init (EShellSidebarClass *class)
 }
 
 static void
-e_shell_sidebar_alert_sink_init (EAlertSinkInterface *interface)
+e_shell_sidebar_alert_sink_init (EAlertSinkInterface *iface)
 {
-	interface->submit_alert = shell_sidebar_submit_alert;
+	iface->submit_alert = shell_sidebar_submit_alert;
 }
 
 static void
 e_shell_sidebar_init (EShellSidebar *shell_sidebar)
 {
-	GtkStyle *style;
 	GtkWidget *widget;
 	GtkWidget *container;
 	PangoAttribute *attribute;
 	PangoAttrList *attribute_list;
-	const GdkColor *color;
+	GdkRGBA bg;
 	const gchar *icon_name;
 
 	shell_sidebar->priv = E_SHELL_SIDEBAR_GET_PRIVATE (shell_sidebar);
@@ -444,9 +459,8 @@ e_shell_sidebar_init (EShellSidebar *shell_sidebar)
 	gtk_widget_set_has_window (GTK_WIDGET (shell_sidebar), FALSE);
 
 	widget = gtk_event_box_new ();
-	style = gtk_widget_get_style (widget);
-	color = &style->bg[GTK_STATE_ACTIVE];
-	gtk_widget_modify_bg (widget, GTK_STATE_NORMAL, color);
+	e_utils_get_theme_color (widget, "theme_bg_color", E_UTILS_DEFAULT_THEME_BG_COLOR, &bg);
+	gtk_widget_override_background_color (widget, GTK_STATE_FLAG_NORMAL, &bg);
 	gtk_widget_set_parent (widget, GTK_WIDGET (shell_sidebar));
 	shell_sidebar->priv->event_box = g_object_ref (widget);
 	gtk_widget_show (widget);
